# -*- rpm-spec -*-

%define current_version 3.2.0.2

%global with_guestfs               0
%global default_hvs                "qemu,xen,lxc"


# End local config

Name: virt-manager
Version: %{current_version}
Release:        1%{?dist}
%global verrel %{version}-%{release}

Summary: Desktop tool for managing virtual machines via libvirt
Group: Applications/Emulators
License: GPLv2+
BuildArch: noarch
URL: https://virt-manager.org/
Source0: %{name}-%{version}.tar.bz2


Requires: virt-manager-common = %{verrel}
Requires: python3-gobject
Requires: gtk3
Requires: libvirt-glib >= 0.0.9
Requires: gtk-vnc2
Requires: spice-gtk3

# We can work with gtksourceview 3 or gtksourceview4, 4th is not in centos8 yes
Requires: gtksourceview3

# virt-manager is one of those apps that people will often install onto
# a headless machine for use over SSH. This means the virt-manager dep
# chain needs to provide everything we need to get a usable app experience.
# Unfortunately nothing in our chain has an explicit dep on some kind
# of usable gsettings backend, so we explicitly depend on dconf so that
# user settings actually persist across app runs
Requires: dconf

# The vte291 package is actually the latest vte with API version 2.91, while
# the vte3 package is effectively a compat package with API version 2.90.
# virt-manager works fine with either, so pull the latest bits so there's
# no ambiguity.
Requires: vte291

# Weak dependencies for the common virt-manager usecase
Recommends: (libvirt-daemon-kvm or libvirt-daemon-qemu)
Recommends: libvirt-daemon-config-network

# Optional inspection of guests
Suggests: python3-libguestfs

BuildRequires: gettext
BuildRequires: python3-devel
BuildRequires: python3-docutils

%description
Virtual Machine Manager provides a graphical tool for administering virtual
machines for KVM, Xen, and LXC. Start, stop, add or remove virtual devices,
connect to a graphical or serial console, and see resource usage statistics
for existing VMs on local or remote machines. Uses libvirt as the backend
management API.


%package common
Summary: Common files used by the different Virtual Machine Manager interfaces
Requires: python3-argcomplete
Requires: python3-libvirt
Requires: python3-libxml2
Requires: python3-requests
Requires: libosinfo >= 0.2.10
# Required for gobject-introspection infrastructure
Requires: python3-gobject-base
# Required for pulling files from iso media with isoinfo
Requires: genisoimage

%description common
Common files used by the different virt-manager interfaces, as well as
virt-install related tools.


%package -n virt-install
Summary: Utilities for installing virtual machines

Requires: virt-manager-common = %{verrel}
# For 'virsh console'
Requires: libvirt-client

Provides: virt-install
Provides: virt-clone
Provides: virt-xml

%description -n virt-install
Package includes several command line utilities, including virt-install
(build and install new VMs) and virt-clone (clone an existing virtual
machine).


%prep
%setup -q


%build
%if %{default_hvs}
%global _default_hvs --default-hvs %{default_hvs}
%endif

./setup.py configure \
    %{?_default_hvs}


%install
./setup.py \
    --no-update-icon-cache --no-compile-schemas \
    install -O1 --root=%{buildroot}
%find_lang %{name}

%if 0%{?py_byte_compile:1}
# https://docs.fedoraproject.org/en-US/packaging-guidelines/Python_Appendix/#manual-bytecompilation
%py_byte_compile %{__python3} %{buildroot}%{_datadir}/virt-manager/
%endif

# Replace '#!/usr/bin/env python3' with '#!/usr/bin/python3'
# The format is ideal for upstream, but not a distro. See:
# https://fedoraproject.org/wiki/Features/SystemPythonExecutablesUseSystemPython
for f in $(find %{buildroot} -type f -executable -print); do
    sed -i "1 s|^#!/usr/bin/env python3|#!%{__python3}|" $f || :
done

mkdir -p %{buildroot}/%{_sysconfdir}/%{name}/presets/
cp presets/* %{buildroot}/%{_sysconfdir}/%{name}/presets/


%files
%doc README.md COPYING NEWS.md
%{_bindir}/%{name}

%{_mandir}/man1/%{name}.1*

%{_datadir}/%{name}/ui/*.ui
%{_datadir}/%{name}/virtManager

%{_datadir}/%{name}/icons
%{_datadir}/icons/hicolor/*/apps/*

%{_datadir}/metainfo/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/glib-2.0/schemas/org.virt-manager.virt-manager.gschema.xml


%files common -f %{name}.lang
%dir %{_datadir}/%{name}

%{_datadir}/%{name}/virtinst

%files -n virt-install
%{_mandir}/man1/virt-install.1*
%{_mandir}/man1/virt-clone.1*
%{_mandir}/man1/virt-xml.1*

%{_datadir}/bash-completion/completions/virt-install
%{_datadir}/bash-completion/completions/virt-clone
%{_datadir}/bash-completion/completions/virt-xml

%{_bindir}/virt-install
%{_bindir}/virt-clone
%{_bindir}/virt-xml

%{_sysconfdir}/%{name}/presets

%changelog
* Fri Jul 23 2021 Dmitry Mishin <dim@virtuozzo.com> 3.2.0.2
 - feat: PSBM-129743 Network \ DNS settings configuration (Mikhail Antonov
<mikhail.antonov@virtuozzo.com>)
 - PSBM-132125 Replace windows unattended floppy by USB disk in newly created
VMs in Vz8 (Efim Shevrin <efim.shevrin@virtuozzo.com>)
 - fix: PSBM-132068 Remove forced nested enabling (Mikhail Antonov
<mikhail.antonov@virtuozzo.com>)

* Thu Jan 14 2021 Dmitry Mishin <dim@virtuozzo.com> 1.5.1.12
 - Change path in container for creating filesystem #PSBM-124521 (Dmitry
Nesterenko <dmitry.nesterenko@virtuozzo.com>)

* Thu Dec 24 2020 Dmitry Mishin <dim@virtuozzo.com> 1.5.1.11
 - Add IP static assignment for network interface #PSBM-123972 (Dmitry
Nesterenko <dmitry.nesterenko@virtuozzo.com>)

* Sat Dec 05 2020 Dmitry Mishin <dim@virtuozzo.com> 1.5.1.10
 - refactor: Move parameters for VMs from preset to default (Mikhail Antonov
<mikhail.antonov@virtuozzo.com>)
 - feat: Windows VZ CT preset (Mikhail Antonov <mikhail.antonov@virtuozzo.com>)
 - feat: force --vcpus 0 for containers (Mikhail Antonov
<mikhail.antonov@virtuozzo.com>)

* Fri Nov 20 2020 Dmitry Mishin <dim@virtuozzo.com> 1.5.1.7
 - feat: PSBM-121790 VEs presets functionality (Mikhail Antonov
<mikhail.antonov@virtuozzo.com>)

* Wed Nov 18 2020 Dmitry Mishin <dim@virtuozzo.com> 1.5.1.6
 - feat: PSBM-122306 Linux container create (Mikhail Antonov
<mikhail.antonov@virtuozzo.com>)

* Thu Oct 22 2020 Denis Silakov <dsilakov@virtuozzo.com> 1.5.1.5
 - Added Makefile.version for vzbuild
 - feat: PSBM-107537 USB 3.0 default controller for x86 (Mikhail Antonov
<amo.mikhail@gmail.com>)
 - feat: PSBM-107537 --blkiotune weight default value (Mikhail Antonov
<mikhail.antonov@virtuozzo.com>)
 - feat: PSBM-107537 --vsock interface w/o default values (Mikhail Antonov
<amo.mikhail@gmail.com>)
 - feat: PSBM-107537 --events on_crash preserve default value (Mikhail Antonov
<amo.mikhail@gmail.com>)
 - feat: PSBM-107537 --cpu mode default value / force vmx feature disable
(Mikhail Antonov <amo.mikhail@gmail.com>)
 - feat: PSBM-107537 --disk default values (Mikhail Antonov
<amo.mikhail@gmail.com>)
 - feat: PSBM-107537 --memtune vz-auto w/ default value (Mikhail Antonov
<mikhail.antonov@virtuozzo.com>)
 - feat: PSBM-107537 --network filterref name / value parameters w/ default
values (Mikhail Antonov <amo.mikhail@gmail.com>)
 - feat: PSBM-107537 --memballoon autodeflate / period w/o default values
(Mikhail Antonov <amo.mikhail@gmail.com>)
 - feat: PSBM-107537 --clock adjustment / basis w/ default values (Mikhail
Antonov <amo.mikhail@gmail.com>)
 - feat: PSBM-107537 --cputune global_period / global_quota w/ default values
(Mikhail Antonov <amo.mikhail@gmail.com>)
 - feat: PSBM-107537 --features vmcoreinfo w/ default value (Mikhail Antonov
<amo.mikhail@gmail.com>)
 - feat: PSBM-107537 --features Hyper-V enlightenments w/ default values
(Mikhail Antonov <amo.mikhail@gmail.com>)
 - Fixes for support creation of docker container #PSBM-107933 (Dmitry
Nesterenko <dmitry.nesterenko@virtuozzo.com>)
 - tests: osdict: fix ordering issue with new osinfo (Christian Ehrhardt
<christian.ehrhardt@canonical.com>)
 - Prep for release 1.5.1 (Cole Robinson <crobinso@redhat.com>)
 - xmlbuilder: Make sure split out XML has xmlns as needed (Cole Robinson
<crobinso@redhat.com>)
 - util: Drop libxml2 error callback (Cole Robinson <crobinso@redhat.com>)
 - manager: Fix mem, disk, net stats graphs (bz 1543896) (Cole Robinson
<crobinso@redhat.com>)
 - Added dummy changelog
 - Added dummy changelog

